aboutsummaryrefslogtreecommitdiffstats
path: root/mail/message-list.h
diff options
context:
space:
mode:
authorNot Zed <NotZed@HelixCode.com>2000-12-24 09:03:14 +0800
committerMichael Zucci <zucchi@src.gnome.org>2000-12-24 09:03:14 +0800
commitfba04bdda76968d230a37b0925fa0d176c755b60 (patch)
tree758dc853a6f1adfe6421f5211c013dbb82bbbbbe /mail/message-list.h
parent5674966eeb7eecfa109ad419f1c997dba69ff0af (diff)
downloadgsoc2013-evolution-fba04bdda76968d230a37b0925fa0d176c755b60.tar
gsoc2013-evolution-fba04bdda76968d230a37b0925fa0d176c755b60.tar.gz
gsoc2013-evolution-fba04bdda76968d230a37b0925fa0d176c755b60.tar.bz2
gsoc2013-evolution-fba04bdda76968d230a37b0925fa0d176c755b60.tar.lz
gsoc2013-evolution-fba04bdda76968d230a37b0925fa0d176c755b60.tar.xz
gsoc2013-evolution-fba04bdda76968d230a37b0925fa0d176c755b60.tar.zst
gsoc2013-evolution-fba04bdda76968d230a37b0925fa0d176c755b60.zip
Merge from camel-mt-branch.
2000-12-24 Not Zed <NotZed@HelixCode.com> * Merge from camel-mt-branch. svn path=/trunk/; revision=7153
Diffstat (limited to 'mail/message-list.h')
-rw-r--r--mail/message-list.h12
1 files changed, 10 insertions, 2 deletions
diff --git a/mail/message-list.h b/mail/message-list.h
index 8e150c8a3d..468f8cc3dc 100644
--- a/mail/message-list.h
+++ b/mail/message-list.h
@@ -2,7 +2,9 @@
#ifndef _MESSAGE_LIST_H_
#define _MESSAGE_LIST_H_
-#include <gnome.h>
+/*#include <gnome.h>*/
+#include <gtk/gtk.h>
+
#include "mail-types.h"
#include <gal/e-table/e-table-scrolled.h>
#include <gal/e-table/e-table-simple.h>
@@ -62,7 +64,7 @@ struct _MessageList {
struct _EMemPool *uid_pool;
/* UID's to hide. Keys in the mempool */
/* IMPORTANT: You MUST have obtained the camel lock, to operate on these structures */
GHashTable *hidden;
struct _EMemPool *hidden_pool;
int hide_unhidden, /* total length, before hiding */
@@ -80,6 +82,9 @@ struct _MessageList {
/* Row-selection and seen-marking timers */
guint idle_id, seen_id;
+
+ /* locks */
+ GMutex *hide_lock; /* for any 'hide' info above */
};
typedef struct {
@@ -123,4 +128,7 @@ void message_list_hide_clear(MessageList *ml);
void message_list_set_threaded(MessageList *ml, gboolean threaded);
void message_list_set_search(MessageList *ml, const char *search);
+#define MESSAGE_LIST_LOCK(m, l) g_mutex_lock(((MessageList *)m)->l)
+#define MESSAGE_LIST_UNLOCK(m, l) g_mutex_unlock(((MessageList *)m)->l)
+
#endif /* _MESSAGE_LIST_H_ */
@@ -62,7 +64,7 @@ struct _MessageList {
struct _EMemPool *uid_pool;
/* UID's to hide. Keys in the mempool */
- /* IMPORTANT: You MUST have obtained the camel lock, to operate on these structures */
+ /* IMPORTANT: You MUST have obtained the hide lock, to operate on this data */
GHashTable *hidden;
struct _EMemPool *hidden_pool;